@@ -1,7 +1,10 @@
-from distutils.core import setup
+try:
+    from setuptools import setup
+except ImportError:
+    from distutils.core import setup
 
 
-dist = setup(
+setup(
     name='cloudpickle_testpkg',
     version='0.0.0',
     description='Package used only for cloudpickle testing purposes',
@@ -9,5 +12,5 @@ dist = setup(
     author_email='cloudpipe@googlegroups.com',
     license='BSD 3-Clause License',
     packages=['_cloudpickle_testpkg'],
-    python_requires='>=3.5',
+    python_requires='>=3.8',
 )
